@@ -384,19 +384,15 @@ class MenuDialog(BaseDialog):
 
         self.maindiv.innerHTML = f"""
             <div class='loggedinas'></div>
-            <div style="min-height: 1px; margin:0; "></div>
+            <div class='divider'></div>
             <a href="/"><img style='width:18px; height:18px;vertical-align:middle;' src='timetagger192.png' />&nbsp;&nbsp;Homepage</a>
-            <a href="/login"><i class='fas'>\uf2f6</i>&nbsp;&nbsp;Login</a>
-            <a href="/logout"><i class='fas'>\uf2f5</i>&nbsp;&nbsp;Logout</a>
-            <a href="/support"><i class='fas'>\uf059</i>&nbsp;&nbsp;Support & FAQs</a>
-            <div style="min-height: 1px; margin:0; "></div>
+            <a href="https://timetagger.app/support"><i class='fas'>\uf059</i>&nbsp;&nbsp;Get tips and help</a>
             <a href="/account"><i class='fas'>\uf2bd</i>&nbsp;&nbsp;Account</a>
-        """
+            <div class='divider'></div>
+        """.rstrip()
 
         # Unpack
         loggedinas = self.maindiv.children[0]
-        loginbut = self.maindiv.children[3]
-        logoutbut = self.maindiv.children[4]
 
         # Valid store?
         if window.store.get_auth:
@@ -412,14 +408,16 @@ class MenuDialog(BaseDialog):
         ):
             is_the_app = False
 
-        # Hide login or logout button, or both
-        if True:
-            loginbut.style.display = "none"
-            logoutbut.style.display = "none"
-        elif logged_in:
-            loginbut.style.display = "none"
-        else:
-            logoutbut.style.display = "none"
+        logged_in  # noqaM
+        # <a href="/login"><i class='fas'>\uf2f6</i>&nbsp;&nbsp;Login</a>
+        # <a href="/logout"><i class='fas'>\uf2f5</i>&nbsp;&nbsp;Logout</a>
+        # # Hide login or logout button, or both
+        # loginbut = self.maindiv.children[3]
+        # logoutbut = self.maindiv.children[4]
+        # if logged_in:
+        #     loginbut.style.display = "none"
+        # else:
+        #     logoutbut.style.display = "none"
 
         # Display sensible text in "header"
         if window.store.__name__.startswith("Demo"):
@@ -441,7 +439,6 @@ class MenuDialog(BaseDialog):
             ("\uf013", store_valid, "Settings", self._show_settings),
             ("\uf02c", store_valid, "Search & manage tags", self._manage_tags),
             ("\uf3fa", is_the_app, "Install this app", self._show_install_instructions),
-            (None, True, None, None),
             ("\uf56f", store_valid, "Import records", self._import),
             ("\uf56e", store_valid, "Export all records", self._export),
         ]:
@@ -449,7 +446,7 @@ class MenuDialog(BaseDialog):
                 continue
             elif title is None:
                 el = window.document.createElement("div")
-                el.setAttribute("style", "min-height: 1px; margin:0;")
+                el.setAttribute("class", "divider")
                 container.appendChild(el)
             else:
                 el = window.document.createElement("a")
@@ -998,7 +995,7 @@ class RecordDialog(BaseDialog):
                 <button type='button'><i class='fas'>\uf00d</i></button>
             </h1>
             <h2><i class='fas'>\uf305</i>&nbsp;&nbsp;Description</h2>
-            <input type="text" style='width: calc(100% - 4em);' />
+            <input type='text' style='width: calc(100% - 4em);' spellcheck='false' />
             <div style='color:#777;'></div>
             <div></div>
             <h2><i class='fas'>\uf017</i>&nbsp;&nbsp;Time</h2>
@@ -1288,6 +1285,112 @@ class RecordDialog(BaseDialog):
         self.close()
 
 
+class ColorDialog(BaseDialog):
+    """Dialog to set the color for a tag combination."""
+
+    def open(self, tagz, callback=None):
+
+        # Put in deterministic order
+        tags = tagz.split(" ")
+        tags.sort()
+        self._tagz = tagz = tags.join(" ")
+
+        self._default_color = utils.color_from_name(self._tagz)
+
+        self.maindiv.innerHTML = f"""
+            <h1><i class='fas'>\uf53f</i>&nbsp;&nbsp;Set color for {tagz}
+                <button type='button'><i class='fas'>\uf00d</i></button>
+                </h1>
+            <input type='text' style='width: 210px; border: 5px solid #eee' spellcheck='false' />
+            <br>
+            <button type='button'><i class='fas'>\uf12d</i> Auto</button>
+            <button type='button' style='margin-left: 2px'><i class='fas'>\uf2f1</i> Random</button>
+            <br>
+            <div style='display: inline-grid; grid-gap: 2px;'></div>
+            <div style='margin-top:2em;'></div>
+            <div style='display: flex;justify-content: flex-end;'>
+                <button type='button' class='actionbutton'><i class='fas'>\uf00d</i>&nbsp;&nbsp;Cancel</button>
+                <button type='button' class='actionbutton submit'><i class='fas'>\uf00c</i>&nbsp;&nbsp;Apply</button>
+            </div>
+        """
+
+        close_but = self.maindiv.children[0].children[-1]
+
+        (
+            _,  # h1
+            self._color_input,
+            _,  # br
+            self._default_button,
+            self._random_button,
+            _,  # br
+            self._color_grid,
+            _,  # gap
+            buttons,
+        ) = self.maindiv.children
+
+        # Connect things up
+        close_but.onclick = self.close
+        buttons.children[0].onclick = self.close
+        buttons.children[1].onclick = self.submit
+        self._color_input.onchange = lambda: self._set_color(self._color_input.value)
+        self._default_button.onclick = self._set_default_color
+        self._random_button.onclick = self._set_random_color
+
+        # Generate palette
+        self._color_grid.style.gridTemplateColumns = "auto ".repeat(utils.PALETTE_COLS)
+        for hex in utils.PALETTE2:
+            el = document.createElement("span")
+            el.style.background = hex
+            el.style.width = "30px"
+            el.style.height = "30px"
+            self._make_clickable(el, hex)
+            self._color_grid.appendChild(el)
+
+        self._set_color(window.store.settings.get_color_for_tagz(tagz))
+
+        super().open(callback)
+        if utils.looks_like_desktop():
+            self._color_input.focus()
+            self._color_input.select()
+
+    def _on_key(self, e):
+        key = e.key.lower()
+        if key == "enter" or key == "return":
+            e.preventDefault()
+            self.submit()
+        else:
+            super()._on_key(e)
+
+    def _make_clickable(self, el, hex):
+        # def clickcallback():
+        #     self._color_input.value = hex
+        el.onclick = lambda: self._set_color(hex)
+
+    def _set_default_color(self):
+        self._set_color(self._default_color)
+
+    def _set_random_color(self):
+        clr = "#" + Math.floor(Math.random() * 16777215).toString(16)
+        self._set_color(clr)
+
+    def _set_color(self, clr):
+        if not clr or clr.lower() in ["auto", "undefined", "null"]:
+            clr = self._default_color
+        if clr != self._color_input.value:
+            self._color_input.value = clr
+        self._color_input.style.borderColor = clr
+
+    def submit(self):
+        clr = self._color_input.value
+        cur_color = window.store.settings.get_color_for_tagz(self._tagz)
+        if clr != cur_color:
+            if clr == self._default_color:
+                window.store.settings.set_color_for_tagz(self._tagz, "")
+            else:
+                window.store.settings.set_color_for_tagz(self._tagz, clr)
+        super().submit()
+
+
 class TagManageDialog(BaseDialog):
     """Dialog to manage tags."""
 
@@ -1297,15 +1400,15 @@ class TagManageDialog(BaseDialog):
             <h1><i class='fas'>\uf02b</i>&nbsp;&nbsp;Search & manage tags
                 <button type='button'><i class='fas'>\uf00d</i></button>
                 </h1>
-            <p>This dialog allows you to search records by tag names, and to
-            rename/remove/merge/split the tags in these records. See the
-            <a href="/support#app">support page</a> for details.<br><br>
+            <p>This tool allows you to search records by tag name(s), and to
+            rename/remove/merge/split the tags in these records. See
+            <a href="https://timetagger.app/articles/tags/#manage" target='new'>this article</a> for details.<br><br>
             </p>
             <div class='formlayout'>
                 <div>Tags:</div>
-                <input type='text' placeholder='Tags to search for' />
+                <input type='text' placeholder='Tags to search for' spellcheck='false' />
                 <div>Replacement:</div>
-                <input type='text' placeholder='Replacement tags'/>
+                <input type='text' placeholder='Replacement tags' spellcheck='false' />
                 <div></div>
                 <button type='button'>Find records</button>
                 <div></div>
@@ -1444,7 +1547,7 @@ class TagManageDialog(BaseDialog):
         lines = [find_html, f"Found {self._records.length} records:<br>"]
         for key in self._records:
             record = window.store.records.get_by_key(key)
-            ds = record.ds
+            ds = record.ds or ""
             date = dt.time2str(record.t1).split("T")[0]
             lines.append(
                 f"""
@@ -1509,11 +1612,13 @@ class ReportDialog(BaseDialog):
         self._tags = tags or []
 
         # Transform time int to dates.
-        self._t1_date = t1_date = dt.time2localstr(dt.floor(t1, "1D")).split(" ")[0]
-        self._t2_date = t2_date = dt.time2localstr(dt.round(t2, "1D")).split(" ")[0]
+        t1_date = dt.time2localstr(dt.round(t1, "1D")).split(" ")[0]
+        t2_date = dt.time2localstr(dt.round(t2, "1D")).split(" ")[0]
         if t1_date != t2_date:
             # The date range is inclusive (and we add 1D later): move back one day
             t2_date = dt.time2localstr(dt.add(dt.round(t2, "1D"), "-1D")).split(" ")[0]
+        self._t1_date = t1_date
+        self._t2_date = t2_date
 
         # Generate preamble
         if self._tags:
@@ -1593,7 +1698,7 @@ class ReportDialog(BaseDialog):
             self._table_element.classList.remove("darkheaders")
 
         # Also apply in the app itself!
-        window.canvas.range.set_range(t1, t2)  # animate_range() will snap
+        window.canvas.range.animate_range(t1, t2, None, False)  # without snap
 
     def _generate_table_rows(self, t1, t2):
 
@@ -1908,8 +2013,7 @@ class ExportDialog(BaseDialog):
             <p>
             The table below contains all your records. This can be
             useful for backups, processing, or to move your data
-            elsewhere. See the <a href='/support#importexport'>support page</a>
-            for details.
+            elsewhere.
             </p><p>&nbsp;</p>
             <div>
                 <span>Date-time format:</span>
@@ -2014,8 +2118,8 @@ class ImportDialog(BaseDialog):
             <p>
             Copy your table data (from e.g. a CSV file, a text file, or
             directly from Excel) and paste it in the text field below.
-            CSV files can be dragged directly into the text field.
-            See the <a href='/support#importexport'>support page</a>
+            CSV files can be dragged into the text field.
+            See <a href='https://timetagger.app/articles/importing/'>this article</a>
             for details.
             </p><p>&nbsp;</p>
             <button type='button'>Analyse</button>
@@ -2142,7 +2246,7 @@ class ImportDialog(BaseDialog):
             "tags": ["tags", "tag"],
             "t1": ["start", "begin", "start time", "begin time"],
             "t2": ["stop", "end", "stop time", "end time"],
-            "description": ["summary", "comment", "ds"],
+            "description": ["summary", "comment", "title", "ds"],
             "projectpath": ["project path"],
             "date": [],
             "duration": [
