@@ -2,4 +2,4 @@
 
 from ._utils import asyncthis, asyncify
 from ._apiserver import api_handler, get_user_db, INDICES
-from ._assets import md2html, create_assets_from_dir
+from ._assets import md2html, create_assets_from_dir, IMAGE_EXTS, FONT_EXTS
